@@ -106,29 +106,6 @@ def on_close(ws):
 
 class Iat(object):
     def __init__(self):
-        # secret_id = "AKIDqTt43ryimaDbkrOgFZgYBj2EBsKdbcFf"
-        # secret_key = "Qef6IGAyaHqFRaaN1QVTHvOceU8ZvCE4"
-        # region = 'ap-hongkong'
-        # token = None
-        # scheme = 'https'
-        # prefix = "kdxfsdk/license/iat"
-        # bucket = "lmxia-1253647560"
-        #
-        # config = CosConfig(Region=region, SecretId=secret_id, SecretKey=secret_key, Token=token, Scheme=scheme)
-        # client = CosS3Client(config)
-        # response = client.list_objects(Bucket=bucket, Prefix=prefix)
-        # objs = [obj for obj in response['Contents'] if str(obj.get("Size", '0')) != '0']
-        # iat_item = choice(objs)
-        # license_key = iat_item.get("Key", "kdxfsdk/license/iat/lmxia.config")
-        # spec_obj = client.get_object(
-        #     Bucket=bucket,
-        #     Key=license_key,
-        # )
-        # fp = spec_obj['Body'].get_raw_stream().read()
-        # license_obj = json.loads(fp)
-        # self.APPID = license_obj.get("APPID")
-        # self.APIKey = license_obj.get("APIKey")
-        # self.APISecret = license_obj.get("APISecret")
         self.APPID = "5cc5623f"
         self.APIKey = "fd98921894fe1bade5b95f1ae75d49d8"
         self.APISecret = "8f57d4b3dbb3fb4b77098df502be780f"
@@ -137,7 +114,7 @@ class Iat(object):
         s1 = threading.Semaphore(0)
 
         wsParam = Ws_Param(self.APPID, self.APIKey, self.APISecret, filename)
-        # websocket.enableTrace(False)
+        websocket.enableTrace(False)
         wsUrl = wsParam.create_url()
         parse_info = {
             "data": ""
